@@ -1,5 +1,6 @@
 require 'logger'
-require 'tzinfo'
+require 'active_support'
+require 'active_support/time'
 
 require 'clockwork/at'
 require 'clockwork/event'
