@@ -10,7 +10,11 @@ module Clockwork
 
       def register(period, job, block, options)
         @events << if options[:from_database]
-          Clockwork::DatabaseEvents::Event.new(self, period, job, (block || handler), options.fetch(:sync_performer), options)
+          synchronizer = options.fetch(:synchronizer)
+          model_attributes = options.fetch(:model_attributes)
+
+          Clockwork::DatabaseEvents::Event.
+            new(self, period, job, (block || handler), synchronizer, model_attributes, options)
         else
           Clockwork::Event.new(self, period, job, block || handler, options)
         end
