@@ -37,7 +37,7 @@ module Clockwork
 
     def error_handler(&block)
       @error_handler = block if block_given?
-      @error_handler
+      @error_handler if instance_variable_defined?("@error_handler")
     end
 
     def on(event, options={}, &block)
@@ -160,7 +160,15 @@ module Clockwork
 
     private
     def events_to_run(t)
-      @events.select{ |event| event.run_now?(t) }
+      @events.select do |event|
+        begin
+          event.run_now?(t)
+        rescue => e
+          log_error(e)
+          handle_error(e)
+          false
+        end
+      end
     end
 
     def register(period, job, block, options)
